@@ -707,11 +707,8 @@ gdm_common_expand_text (const gchar *text)
 	      g_string_append (str, name.sysname);
 	      break;
 	    case 't':
-	      g_string_append_printf (str, "%d", gdm_timed_delay);
-              if (gdm_timed_delay != 1)
-		g_string_append (str, _(" seconds"));
-              else
-		g_string_append (str, _(" second"));
+	      g_string_append_printf (str, ngettext("%d second", "%d seconds", gdm_timed_delay),
+				      gdm_timed_delay);
 	      break;
 	    case 'u':
 	      g_string_append (str, ve_sure_string (g_getenv("GDM_TIMED_LOGIN_OK")));
