@@ -20,20 +20,19 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 /* For clist */
 #undef GTK_DISABLE_DEPRECATED
 
 #include <stdlib.h>
+
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
 #include "ve-i18n.h"
-
 #include "ve-misc.h"
 #include "ve-miscui.h"
-
 #include "glade-helper.h"
 
 static void glade_helper_no_interface (const char *filename);
